/*
 * NDDEAPI.H  include file for dde share apis
 *
 * Contains definitions and function prototypes for the APIs in
 * NDDEAPI.LIB/NDDEAPI.DLL.
 *
 * Microsoft Windows for Workgroups Version 3.10 Beta 3
 * Copyright (c) 1985-1992, Microsoft Corp. All rights reserved.
 */


#ifndef          NDDEAPI_INCLUDED
#define          NDDEAPI_INCLUDED

//Error codes returned from APIs that return UINT.
#define NDDE_NO_ERROR                  0

#define NDDE_ACCESS_DENIED             1
#define NDDE_BUF_TOO_SMALL             2
#define NDDE_ERROR_MORE_DATA           3
#define NDDE_INVALID_SERVER            4
#define NDDE_INVALID_SHARE             5
#define NDDE_INVALID_PARAMETER         6
#define NDDE_INVALID_LEVEL             7
#define NDDE_INVALID_PASSWORD          8
#define NDDE_INVALID_ITEMNAME          9
#define NDDE_INVALID_TOPIC             10
#define NDDE_INTERNAL_ERROR            11
#define NDDE_OUT_OF_MEMORY             12
#define NDDE_INVALID_APPNAME           13
#define NDDE_NOT_IMPLEMENTED           14
#define NDDE_SHARE_ALREADY_EXIST       15
#define NDDE_SHARE_NOT_EXIST           16
#define NDDE_INVALID_FILENAME	       17
#define NDDE_NOT_RUNNING               18
#define NDDE_INVALID_WINDOW            19
#define NDDE_INVALID_SESSION           20


//String size constants
#define CNLEN                          15          //Computername
#define UNCLEN                         (CNLEN+2)   //UNC name

#define MAX_NDDESHARENAME              64
#define MAX_PASSWORD                   15
#define MAX_USERNAME                   15
#define MAX_DOMAINNAME                 15
#define MAX_APPNAME                    255
#define MAX_TOPICNAME                  255
#define MAX_ITEMNAME                   255


//Permission bits for NDdeShareAdd
#define NDDEACCESS_REQUEST             0x00000001L
#define NDDEACCESS_ADVISE              0x00000002L
#define NDDEACCESS_POKE                0x00000004L
#define NDDEACCESS_EXECUTE             0x00000008L
#define NDDEACCESS_START_APP           0x00000010L

#define NDDEACCESS_ALL                 0x0000001FL
#define NDDEACCESS_EXCLUDEEXECUTE      0x00000017L
#define NDDEACCESS_EXCLUDESTARTAPP     0x0000000FL



/*
 * NDDESHAREITEMINFO
 * Contains information about additional item security.  When a server
 * shares more than one item it provides an array of these structures
 * in the NDDESHAREINFO structure below in the call to NDdeShareAdd.
 */

typedef struct NDdeShareItemInfo_tag
    {
    LPSTR       lpszItem;
    DWORD       dwPermissions;
    } NDDESHAREITEMINFO, *PNDDESHAREITEMINFO, FAR *LPNDDESHAREITEMINFO;


/*
 * NDDESHAREINFO
 * Contains information about a NDDE share for use with the NDdeShareAdd API.
 */

typedef struct NDdeShareInfo_tag
    {
    char                    szShareName[MAX_NDDESHARENAME+1];
    LPSTR                   lpszTargetApp;
    LPSTR                   lpszTargetTopic;
    LPBYTE                  lpbPassword1;
    DWORD                   cbPassword1;
    DWORD                   dwPermissions1;
    LPBYTE                  lpbPassword2;
    DWORD                   cbPassword2;
    DWORD                   dwPermissions2;
    LPSTR                   lpszItem;
    LONG                    cAddItems;
    LPNDDESHAREITEMINFO     lpNDdeShareItemInfo;
    } NDDESHAREINFO, *PNDDESHAREINFO, FAR *LPNDDESHAREINFO;



/*
 * NDDESESSINFO
 * Contains information about a NDDE session for use with the
 * NDdeSessionEnum API.
 */

//Status field defines
#define NDDESESS_CONNECTING_WAIT_NET_INI        1
#define NDDESESS_CONNECTING_WAIT_OTHR_ND        2
#define NDDESESS_CONNECTED                      3
#define NDDESESS_DISCONNECTING                  4

typedef struct NDdeSessInfo_tag
    {
    char        szClientName[UNCLEN+1];
    short       Status;
    DWORD       UniqueID;              //Distinguishs identically named clients
    } NDDESESSINFO, * PNDDESESSINFO, FAR * LPNDDESESSINFO;



/*
 * NDDECONNINFO
 * Contains information about a NDDE conversaiont for use with ???
 */

//Status field defines

#define NDDECONN_WAIT_LOCAL_INIT_ACK            1
#define NDDECONN_WAIT_NET_INIT_ACK              2
#define NDDECONN_OK                             3
#define NDDECONN_TERMINATING                    4
#define NDDECONN_WAIT_USER_PASSWORD             5

typedef struct NDdeConnInfo_tag
    {
    LPSTR   lpszShareName;
    short   Status;
    short   reserved;
    } NDDECONNINFO, * PNDDECONNINFO, FAR * LPNDDECONNINFO;






/*
 * API FUNCTION PROTOTYPES
 * Separated into groupings of Share Management, Session and
 * Connection Management, Information Retrieval, and Utility.
 *
 * PLEASE NOTE!!  The names defined using macros are the names
 * we'll use in releases after Beta 3.  For now, the exports from
 * NDDEAPI.DLL and those entries in NDDEAPI.LIB are prefixed with Dde
 * instead of NDde.  In the next release, we'll have NDde in the
 * DLL and LIB so for Beta 3, use the macros!
 */


//Share Management
UINT WINAPI NDdeShareAdd
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    UINT                uLevel,             //Info level: must be 2
    LPNDDESHAREINFO     lpNDdeShareInfo,    //Pointer to the share info
    DWORD               cbShareInfo         //Sizeof lpNDdeShareInfo
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeShareDel
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    LPSTR               lpszShareName,      //Name of share to delete
    UINT                uReserved           //Reserved
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeShareEnum
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    UINT                uLevel,             //0 for doubly-null terminated list
    LPBYTE              lpNames,            //Pointer to buffer to receive the
                                            //doubly-null term list of shares
    DWORD               cbNames,            //Size of the lpNames buffer
    LPDWORD             lpnEntriesRead,     //Number of names returned
    LPDWORD             lpcbTotalAvailable  //Number of bytes available
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeShareGetInfo
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    LPSTR               lpszShareName,      //Name of share
    UINT                uLevel,             //Info level: must be 2
    LPNDDESHAREINFO     lpNDdeShareInfo,    //Structure to receive the info
    DWORD               cbShareInfo,        //Size of lpNDdeShareInfo
    LPDWORD             lpcbTotalAvailable, //Number of bytes available
    LPWORD              lpnItems            //Receives gets number of added items
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeShareSetInfo
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    LPSTR               lpszShareName,      //Name of share
    UINT                uLevel,             //Info level must be 2
    LPNDDESHAREINFO     lpNDdeShareInfo,    //Points to structure with info
    DWORD               cbShareInfo,        //Size of lpNDdeShareInfo
    WORD                sParmNum            //Parameter index: must be 0
    );  //Returns NDDE_* error code.




//Session and Connection Management

UINT WINAPI NDdeSessionEnum
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    UINT                uLevel,             //Info level:  must be 1
    LPNDDESESSINFO      lpNDdeSessInfo,     //Pointer to structure to get info
    DWORD               cbSessInfo,         //Size of lpNDdeSessInfo
    LPDWORD             lpcbTotalAvailable, //Received number of bytes filled
    LPDWORD             lpnItems            //Received number of names
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeConnectionEnum
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    LPSTR               lpszClientName,     //Name of client to enum shares from;
                                            //if NULL, enumerate from all
    DWORD               UniqueID,           //Used to distinguish same-name clients
    UINT                uLevel,             //Info level:  must be 1
    LPNDDECONNINFO      lpNDdeConnInfo,     //Pointer to receive connection info
                                            //which is a doubly-null terminated
                                            //list of name strings.
    DWORD               cbConnInfo,         //Size of lpNDdeConnInfo
    LPDWORD             lpcbTotalAvailable, //Receives number of bytes filled
    LPDWORD             lpnItems            //Receives number of items returned
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeSessionClose
    (
    LPSTR               lpszServer,         //Server to execute on: must be NULL
    LPSTR               lpszClientName,     //Client to close
    DWORD               UniqueID            //To identify same-named clients
    );  //Returns NDDE_* error code.



//Information Retrieval

UINT WINAPI NDdeGetClientInfo
    (
    HWND                hWndClient,         //Your window, or the guy you talk to?
    LPSTR               lpszClientNode,     //Buffer to receive the client name
    DWORD               cchClientNode,      //Size of lpszClientNode
    LPSTR               lpszClientApp,      //Buffer to receive the app name
    DWORD               cchClientApp        //Size of lpszClientApp
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeGetNodeName
    (
    LPSTR               lpszNodeName,       //Buffer in which to store the name
    DWORD               cchNodeName         //Length of the lpszNodeName buffer
    );  //Returns NDDE_* error code.


UINT WINAPI NDdeGetErrorString
    (
    UINT                uErrorCode,         //Error code to get string for
    LPSTR               lpszError,          //Buffer to hold error string
    DWORD               cchError            //Length of lpszError
    );  //Returns NDDE_* error code.




//Utility
HWND WINAPI NDdeGetWindow(void);

/*
 * These should be in NDDEAPI.DLL for consistency, but are not there
 * currently.  You should in no way depend on them.
 */
#define NDdeIsValidAppName(a)     TRUE
#define NDdeIsValidItemName(a)    TRUE

//Name validation APIs
BOOL WINAPI NDdeIsValidShareName(LPSTR pszShare);
BOOL WINAPI NDdeIsValidPassword(LPSTR  pszPassword);
BOOL WINAPI NDdeIsValidTopic(LPSTR pszTopic);


#endif //NDDEAPI_INCLUDED
